@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 10284 2017-09-10 17:17:32Z David $
+# $Id: Mailer.py 10436 2017-11-05 03:14:46Z David $
 #
-# Copyright (c) 2014 Nuwa Information Co., Ltd, All Rights Reserved.
+# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
 # Licensed under the Proprietary License,
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
 #
 # $Author: David $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10284 $
+# $Revision: 10436 $
 
 import os
 import random
@@ -28,6 +28,8 @@ from django.utils.encoding import smart_str, smart_unicode
 from django.contrib.sites.models import Site
 from django.template import Context, Template
 from django.template.loader import render_to_string
+from django.conf import settings
+from django.core.urlresolvers import reverse
 
 from emencia.django.newsletter.mailer import Mailer
 from emencia.django.newsletter.utils.tokens import tokenize
@@ -235,15 +237,23 @@ class CloudMailer(Mailer):
 
         @param content The content of replaced.
         """
+
+        if (hasattr(settings, 'SECURE_PROXY_SSL_HEADER') and
+            settings.SECURE_PROXY_SSL_HEADER):
+            protocol = 'https'
+        else:
+            protocol = 'http'
+
         mapping = (
-            ("NEWSLETTER_SITE_LINK",
-             "{{ domain }}{% url 'newsletter_newsletter_contact' "
-             "slug=newsletter.slug,uidb36=uidb36 token=token %}"),
+            ("http://NEWSLETTER_SITE_LINK",
+             ("%s://{{ domain }}{%% url 'newsletter_newsletter_contact' " % (
+                 protocol, ) +
+             "slug=newsletter.slug uidb36=uidb36 token=token %}")),
             ("http://NEWSLETTER_UNSUBSCRIBE_LINK",
-             "{% if uidb36 and token %}http://{{ domain }}"
+             ("{%% if uidb36 and token %%}%s://{{ domain }}" % (protocol, ) +
              "{% url 'newsletter_mailinglist_unsubscribe' "
              "slug=newsletter.slug uidb36=uidb36 token=token %}"
-             "{% else %}#{% endif %}"),
+             "{% else %}#{% endif %}")),
         )
 
         for (key, _c) in mapping:
@@ -321,6 +331,7 @@ class CloudMailer(Mailer):
         resultMessage = ''
         newsletterId = self.newsletter.id
         contactId = contact.id
+
         try:
             self.logger.info(
                 '[%d]_START: Send mail to contact<%d>.' %
@@ -333,6 +344,7 @@ class CloudMailer(Mailer):
                 subject = self.build_title_content(contact)
                 replyTo = smart_str(self.newsletter.header_reply)
                 contentHtml = self.buildEmailContent(contact)
+                a = 1/0
                 result = self.smtp.sendMail(
                     contact,
                     subject,
@@ -341,12 +353,14 @@ class CloudMailer(Mailer):
                     contentHtml,
                     attachments=self.attachments)
                 resultMessage = 'Send mail success.'
+                
             else:
                 message = self.build_message(contact)
-                self.smtp.sendmail(
-                    smart_str(self.newsletter.header_sender),
-                    contact.email,
-                    message.as_string())
+                content = message.as_string()
+                sender = u'test@nuwainfo.com'
+                to = contact.email
+
+                self.smtp.sendmail(sender, to, content)
                 result = True
                 resultMessage = 'Send mail success.'
 
@@ -368,9 +382,11 @@ class CloudMailer(Mailer):
         except Exception as e:
             _eMsg = getComment(e)
             resultMessage = 'Send mail failed: %s.' % _eMsg
-            self.logger.error(
-                '[%d]_FAILED: Send mail to contact<%d> failed, %s.' %
-                (newsletterId, contactId, _eMsg))
+            errorMessage = (
+                '[%d]_FAILED: Send mail to contact<%d> failed,\n %s.' %
+                (newsletterId, contactId, _eMsg)
+            )
+            self.logger.error(errorMessage)
 
             if (isinstance(e, RetryAndSendException) or
                 isinstance(e, SendMessageException)):
@@ -389,8 +405,10 @@ class CloudMailer(Mailer):
                 except Exception as e:
                     self.logger.error(
                         '[%d]_GET_ERROR_INFO_FAILED: contact<%d>.' %
-                        (newsletterId, contactId))
+                        (newsletterId, contactId)
+                    )
                     status = ContactMailingStatus.ERROR
+
             else:
                 status = ContactMailingStatus.ERROR
         finally:
@@ -398,8 +416,13 @@ class CloudMailer(Mailer):
                 '[%d]_END: Send mail to contact<%d> end.' %
                 (newsletterId, contactId))
 
+        # FIXME # If no wait, it might be no record contactmailingstatus.
+        # time.sleep(3)
         ContactMailingStatus.objects.create(
-            newsletter=self.newsletter, contact=contact, status=status)
+            newsletter=self.newsletter, contact=contact, status=status
+        )
+
+        # FIXME # Add record error message  to db here.
 
         return {'result': result , 'message': resultMessage, 'id': contactId}
 
