@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10403 2017-10-24 08:52:47Z David $
+# $Id: views.py 10436 2017-11-05 03:14:46Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10403 $
+# $Revision: 10436 $
 
 from django.shortcuts import render_to_response, get_object_or_404
 from django.utils.translation import ugettext_lazy as _
@@ -33,6 +33,7 @@ from Theophrastus.models import (MailingList, Newsletter,
                                 ContactMailingStatus, Contact)
 from Theophrastus.cloud.Mailer import CloudMailer
 from Theophrastus.newsletter_extension.models import Header, Footer
+from Theophrastus.cloud.service import CloudService
 
 @staff_member_required
 @jsonpCallback(noPadding=True)
@@ -125,13 +126,17 @@ def resendErrorContact(request, newsletterId):
                'object_id': newsletter.pk,
                'app_label': opts.app_label}
 
+    # TODO: set --> distinct()
     sentContactIdList = set(
         ContactMailingStatus.objects.filter(
-            newsletter_id=newsletter.id, status=0).values_list('contact_id'))
+            newsletter_id=newsletter.id, status=ContactMailingStatus.SENT
+        ).values_list('contact_id').distinct())
 
     contactIdSet = set(
         ContactMailingStatus.objects.filter(
-            newsletter_id=newsletter.id, status=1).exclude(
+            newsletter_id=newsletter.id, 
+            status=ContactMailingStatus.ERROR
+        ).exclude(
                 contact_id__in=sentContactIdList).values_list('contact_id'))
 
     if contactIdSet:
@@ -157,5 +162,38 @@ def resendErrorContact(request, newsletterId):
     return render_to_response('newsletter/newsletter_historic.html',
                               context, context_instance=RequestContext(request))
 
+def viewErrorDetails(request, slug, contactMailingStatusId):
+    """
+    Display the error message of a newsletter contact.
+
+    @param request Request instance.
+    @param slug Newsletter's slug.
+    @param cloudmailinformationId Id of CloudMailInformation.
+    """
+
+    contactMailingStatus = ContactMailingStatus.objects.filter(
+                                id=contactMailingStatusId)[0]
+    opts = Newsletter._meta
+    cloudSrv = CloudService.getInstance()
+    newsletter = get_object_or_404(Newsletter, slug=slug)
+    obj = cloudSrv.getCloudMailInformation(
+        newsletter_id=contactMailingStatus.newsletter.id,
+        contact_id=contactMailingStatus.contact.id,
+        errorOnNotFound=False
+    )
+    
+    context = {
+        'title': _('Error of contact: %s') % obj.contact_id,
+        'original': newsletter,
+        'opts': opts,
+        'object_id': newsletter.pk,
+        'app_label': opts.app_label,
+        'content': obj.message
+    }
+    return render_to_response(
+        'NewsletterHistoricErrorDetail.html',
+        context,
+        context_instance=RequestContext(request)
+    )
 
 
