@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 10403 2017-10-24 08:52:47Z David $
+# $Id: urls.py 10436 2017-11-05 03:14:46Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-10-24 16:52:47 +0800 (Tue, 24 Oct 2017) $
-# $Revision: 10403 $
+# $Date: 2017-11-05 11:14:46 +0800 (Sun, 05 Nov 2017) $
+# $Revision: 10436 $
 
 from django.conf.urls import url, include, patterns
 from newsletter_extension import views as newsletterExtensionViews 
@@ -59,4 +59,10 @@ urlpatterns = patterns('',
     # resend error contact.
     url(r'^newsletters/resend/(?P<newsletterId>\w+)',
         newsletterExtensionViews.resendErrorContact, name='resendErrorContact'),
+
+    url(
+        r'^tracking/historic/(?P<slug>[-\w]+)/errors/'
+        r'(?P<contactMailingStatusId>\w+)',
+        newsletterExtensionViews.viewErrorDetails,
+        name='Theophrastus.newsletter_extension.views.viewErrorDetails'),
 )
